Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ColumnsToProto ¶
func ColumnsToProto(columns []*model.ColumnInfo, pkIsHandle bool) []*tipb.ColumnInfo
ColumnsToProto converts a slice of model.ColumnInfo to a slice of tipb.ColumnInfo.
func FieldTypeFromPBColumn ¶
func FieldTypeFromPBColumn(col *tipb.ColumnInfo) *types.FieldType
FieldTypeFromPBColumn creates a types.FieldType from tipb.ColumnInfo.
Types ¶
type PartialResult ¶
type PartialResult interface {
// Next returns the next rowData of the sub result.
// If no more row to return, rowData would be nil.
Next() (handle int64, rowData []byte, err error)
// Close closes the partial result.
Close() error
}
PartialResult is the result from a single region server.
type SelectResult ¶
type SelectResult interface {
// Next gets the next partial result.
Next() (PartialResult, error)
// Close closes the iterator.
Close() error
// Fetch fetches partial results from client.
// The caller should call SetFields() before call Fetch().
Fetch(ctx goctx.Context)
}
SelectResult is an iterator of coprocessor partial results.
func Select ¶
func Select(client kv.Client, ctx goctx.Context, req *tipb.SelectRequest, keyRanges []kv.KeyRange, concurrency int, keepOrder bool) (SelectResult, error)
Select do a select request, returns SelectResult. concurrency: The max concurrency for underlying coprocessor request. keepOrder: If the result should returned in key order. For example if we need keep data in order by
scan index, we should set keepOrder to true.
func SelectDAG ¶
func SelectDAG(client kv.Client, ctx goctx.Context, dag *tipb.DAGRequest, keyRanges []kv.KeyRange, concurrency int, keepOrder bool, desc bool) (SelectResult, error)
SelectDAG sends a DAG request, returns SelectResult. concurrency: The max concurrency for underlying coprocessor request. keepOrder: If the result should returned in key order. For example if we need keep data in order by
scan index, we should set keepOrder to true.